;; Generated package description from denote-menu.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "denote-menu" "1.4.0.0.20250317.132443" "View denote files in a tabulated list." '((emacs "28.1") (denote "3.0.0")) :commit "13ffe8a5c180b826ec55570a981931f56d8e2323" :authors '(("Mohamed Suliman" . "sulimanm@tcd.ie")) :maintainer '("Mohamed Suliman" . "sulimanm@tcd.ie") :url "https://github.com/namilus/denote-menu")
